/*********************************************************************************************
 * (c) COPYRIGHT 2020 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * conversion HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : conversion.h
 * CREATION DATE : Apr 7, 2020
 * TARGET        : generic
 *
 *********************************************************************************************/
#ifndef _CONVERSION_H_
#define _CONVERSION_H_

/** @ingroup libnmapp
 * @defgroup conversion Conversion
 * Provides converstion functions like string to int, etc.
 */

#include <nmapp/types/nm-types.h>

#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        GLOBAL DECLARATIONS
 *********************************************************************************************/



/*********************************************************************************************
 *        GLOBAL FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
/** @ingroup conversion
* @brief str2int Convert a String To a signed Integer (32bit)
* Returns a signed 32bit integer of the string provided by argument str.\n\n
*
* @param str    A pointer to the string to convert
* @return The converted result - throws a conversion exception on error
*/
int32_t str2int(char *str);
//--------------------------------------------------------------------------------------------
/** @ingroup conversion
* @brief Convert a String To an Unsigned Integer (32bit)
* Returns an unsigned 32bit integer of the string provided by argument str
*
* @param str    A pointer to the string to convert
* @return The converted result - throws a conversion exception on error
*/
uint32_t str2uint(char *str);
//--------------------------------------------------------------------------------------------
/** @ingroup conversion
* @brief Convert a String To Hex (32bit)
* Returns a 32bit hex value of the string provided by argument str
*
* @param str    A pointer to the string to convert
* @return The converted result - throws a conversion exception on error
*/
uint32_t str2hex(char *str);
//--------------------------------------------------------------------------------------------
/** @ingroup conversion
* @brief Convert a String To Float (64bit)
* Returns a 64bit floating point value of the string provided by argument str
*
* @param str    A pointer to the string to convert
* @return The converted result - throws a conversion exception on error
*/
float64_t str2float(char *str);


#ifdef __cplusplus
}
#endif

#endif /* INCLUDE_NMAPP_CONVERSION_CONVERSION_H_ */
