/*********************************************************************************************
 * (c) COPYRIGHT 2020 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * FileOperation HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : FileOperation.h
 * CREATION DATE : Apr 2, 2020
 * TARGET        : embedded Linux
 *
 *********************************************************************************************/
#ifndef _FILE_FILEOPERATION_H_
#define _FILE_FILEOPERATION_H_

/** @ingroup libnmapp
 * @defgroup FileOperation File Operations
 * Realizes the File Operation Interface by providing file operation functions such as
 * open-, close-, move-, copy file and read/write from/to file.
 */


#include <nmapp/types/nm-types.h>
#include <nmapp/logging/ILog.h>
#include "IFileOperation.h"

#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        GLOBAL DECLARATIONS
 *********************************************************************************************/

/** File Operation object reference */
typedef struct __FileOperationPrivate * FileOperationRef;

/*********************************************************************************************
 *        GLOBAL FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
/** @ingroup FileOperation
 * @brief Creates a File Operation Instance
 * Creates a file operation instance and realizes the file operation interface
 *
 * @param logRef    A reference to the logger to use
 * @return A reference to the created instance
 */
FileOperationRef FileOperation_create(ILogRef logRef);
//--------------------------------------------------------------------------------------------
/** @ingroup FileOperation
 * @brief Destroy a File Operation Instance
 * Destroys a file operation instance
 *
 * @param me     A reference to my instance
 */
void FileOperation_destroy(FileOperationRef me);
//--------------------------------------------------------------------------------------------
/** @ingroup FileOperation
 * @brief Get a File Operation Interface Reference
 * Returns the reference of the file operation interface
 *
 * @param me     A reference to my instance
 * @return The reference of the interface
 */
IFileOperationRef FileOperation_getItfRef(FileOperationRef me);


#ifdef __cplusplus
}
#endif

#endif /* _FILE_FILEOPERATION_H_ */
