/*********************************************************************************************
 * (c) COPYRIGHT 2021 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * IoctlOperation HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : IoctlOperation.h
 * CREATION DATE : Oct 21, 2021
 * TARGET        : embedded Linux
 *
 *********************************************************************************************/
#ifndef INCLUDE_NMAPP_FILE_IOCTLOPERATION_H_
#define INCLUDE_NMAPP_FILE_IOCTLOPERATION_H_

/** @ingroup libnmapp
 * @defgroup IoctlOperation IOCTL Operation
 * Realizes the IOCTL operation interface by providing the IOCTL request call function.
 */

#include <nmapp/types/nm-types.h>
#include <nmapp/logging/ILog.h>
#include "IIoctlOperation.h"

#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        GLOBAL DECLARATIONS
 *********************************************************************************************/

/** IOCTL Operation object reference */
typedef struct __IoctlOperationPrivate * IoctlOperationRef;


/*********************************************************************************************
 *        GLOBAL FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
/** @ingroup IoctlOperation
 * @brief Creates an IOCTL Operation Instance
 * Creates an IOCTL operation instance and realizes the IOCTL operation interface
 *
 * @param logRef    A reference to the logger to use
 * @return A reference to the created instance
 */
IoctlOperationRef IoctlOperation_create(ILogRef logRef);
//--------------------------------------------------------------------------------------------
/** @ingroup IoctlOperation
 * @brief Destroy an IOCTL Operation Instance
 * Destroys an IOCTL operation instance
 *
 * @param me     A reference to my instance
 */
void IoctlOperation_destroy(IoctlOperationRef me);
//--------------------------------------------------------------------------------------------
/** @ingroup IoctlOperation
 * @brief Get an IOCTL Operation Interface Reference
 * Returns the reference of the IOCTL operation interface
 *
 * @param me     A reference to my instance
 * @return The reference of the interface
 */
IIoctlOperationRef IoctlOperation_getItfRef(IoctlOperationRef me);


#ifdef __cplusplus
}
#endif

#endif /* INCLUDE_NMAPP_FILE_IOCTLOPERATION_H_ */
