/*********************************************************************************************
 * (c) COPYRIGHT 2020 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * Logging Interface PROTECTED HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : ILog-protected.h
 * CREATION DATE : Mar 10, 2020
 * TARGET        : embedded Linux
 *
 *********************************************************************************************/
#ifndef I_LOG_PROTECTED_H_
#define I_LOG_PROTECTED_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <nmapp/types/nm-types.h>
#include <nmapp/logging/ILog.h>

/*********************************************************************************************
 *        PRIVATE DECLARATIONS
 *********************************************************************************************/

/**
 * Forward declaration for the class which realizes this interface
 */
typedef void * ILogImplRef;


/*********************************************************************************************
 *        PRIVATE FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
/**
 * Constructor for this interface (shall only be called from the realizing class)
 *
 * @note this function must be called by the constructor of the realizing class (this allows
 * kind of c-inheritance from an abstract (pure virtual) c-class or in other words
 * realizing this interface)
 *
 * @param implRef         the reference to the realizing object (used later on to pass back to
 *                        the realized functions to get the correct object in heap)
 * @param isSysLogger     true = this is the syslogger instance (used when reference passed as NULL)
 *                        false, this is a regular logger instance (used to determine different
 *                        logging facilities)
 * @param maxLogLevel     The default max log level for this facility if not reconfigured
 * @param log_msg         pointer to the log msg function for a specific logger instance
 *
 * @return                the reference of the new created interface (shall be stored in the
 *                        object ctx of the realizing class)
 */
ILogRef ILog_ctor(ILogImplRef implRef, bool isSysLogger, LogLevel_t maxLogLevel,
                  void (*log_msg)(ILogImplRef me, LogLevel_t logLevel, const char * msg, va_list args));

//--------------------------------------------------------------------------------------------
/**
 * Destructor of the interface.
 *
 * @param me the reference to myself
 */
void ILog_destroy(ILogRef me);


#ifdef __cplusplus
}
#endif

#endif
/************************************END OF FILE*********************************************/
