/*********************************************************************************************
 * (c) COPYRIGHT 2020 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * Daemonizer HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : daemonizer.h
 * CREATION DATE : Apr 2, 2020
 * TARGET        : embedded Linux
 *
 *********************************************************************************************/
#ifndef _PROCESS_DAEMONIZER_H_
#define _PROCESS_DAEMONIZER_H_

#include <unistd.h>

/** @ingroup libnmapp
 * @defgroup Daemonizer Daemonizer
 * Provides functions for daemonizing.
 */
#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        GLOBAL DECLARATIONS
 *********************************************************************************************/



/*********************************************************************************************
 *        GLOBAL FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
/** @ingroup Daemonizer
 * @brief Daemonize
 * Daemonizes an actual process
 *
 * @param pidFile   The file name of the PID file
 * @return the pid of the daemon
 */
pid_t Daemonizer_daemonize(const char *pidFile);

//--------------------------------------------------------------------------------------------
/** @ingroup Daemonizer
 * @brief Write PID File
 * Writes a PID file
 *
 * @param pidFile   The file name of the PID file
 * @param pid       The pid to write in the PID file; if -1 the pid is taken from the running process
 */
void Daemonizer_writePidFile(const char *pidFile, int pid);

//--------------------------------------------------------------------------------------------
/** @ingroup Daemonizer
 * @brief Remove PID File
 * Removes a PID file
 *
 * @param pidFile   The file name of the PID file
 */
void Daemonizer_removePidFile(const char *pidFile);


#ifdef __cplusplus
}
#endif

#endif /* _PROCESS_DAEMONIZER_H_ */
