/*********************************************************************************************
 * (c) COPYRIGHT 2021 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * UnixInitSys HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : UnixInitSys.h
 * CREATION DATE : Jan 18, 2021
 * TARGET        : embedded Linux
 *
 *********************************************************************************************/
#ifndef _SYS_UNIXINITSYS_H_
#define _SYS_UNIXINITSYS_H_

/** @ingroup libnmapp
 * @defgroup unixinitsys Unix Init-System
 * Encapsulates functions of the unix init system, e.g. systemd and implements the
 * interface IUnixInitSys
 */

#include <nmapp/types/nm-types.h>
#include <nmapp/logging/ILog.h>
#include "IUnixInitSys.h"


#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        GLOBAL DECLARATIONS
 *********************************************************************************************/

/** Unix InitSys object reference */
typedef struct __UnixInitSysPrivate * UnixInitSysRef;


#define SYSLOG_MSG_FORMAT_STR           " [%s] %s %s: %s"

extern const char* SYSLOG_LEVEL_NAME[LOG_LEVEL_MAX];


/*********************************************************************************************
 *        GLOBAL FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
/** @brief Create Unix Init System Instance
 * Creates an instance of the unix init system.
 *
 * @param logRef    A reference to the logger to use
 * @param appName   The name of the application (used for logging)
 * @param useSysLog true if syslog shall be used, false if journal shall be used
 * @return A reference to the created instance
 */
UnixInitSysRef UnixInitSys_create(ILogRef logRef, const char* appName, bool useSysLog);
//--------------------------------------------------------------------------------------------
/** @brief Destroy Unix Init System Instance
 * Destroys an instance of the unix init system.
 *
 * @param me        A reference to a unix init sys instance
 */
void UnixInitSys_destroy(UnixInitSysRef me);
//--------------------------------------------------------------------------------------------
/** @brief Get a Unix Init-Sys Interface Reference
 * Returns the reference of the unix init-sys interface
 *
 * @param me     A reference to my instance
 * @return The reference of the interface
 */
IUnixInitSysRef UnixInitSys_getItfRef(UnixInitSysRef me);


#ifdef __cplusplus
}
#endif

#endif /* _SYS_UNIXINITSYS_H_ */
