/*********************************************************************************************
 * (c) COPYRIGHT 2021 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * IIoctlOperation HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : IIoctlOperation.h
 * CREATION DATE : Oct 21, 2021
 * TARGET        : generic
 *
 *********************************************************************************************/
#ifndef INCLUDE_NMAPP_FILE_IIOCTLOPERATION_H_
#define INCLUDE_NMAPP_FILE_IIOCTLOPERATION_H_

/** @ingroup libnmapp
 * @defgroup IIoctlOperation IOCTL Operation Interface
 * Provides an interface for ioctl calls.
 */

#include <nmapp/types/nm-types.h>


#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        GLOBAL DECLARATIONS
 *********************************************************************************************/

/** Reference to the created interface instance */
typedef struct __IIoctlOperationProtected * IIoctlOperationRef;

/** Forward declaration for the class which realizes this interface */
typedef void * IIoctlOperationImplRef;


/*********************************************************************************************
 *        GLOBAL FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
/** @ingroup IIoctlOperation
 * @brief Constructor of an IOCTL Operation Interface
 * Creates an IOCTL operation interface instance
 *
 * @param arg    The argument description
 * @return The reference to the created instance
 */
IIoctlOperationRef IIoctlOperation_ctor(IIoctlOperationImplRef implRef,
                                        int (*request)(IIoctlOperationImplRef implRef, const char* fileName, unsigned long request, void* argp),
                                        void (*mmcRequest)(IIoctlOperationImplRef implRef, const char* devPath, void* pIocCmd, void* pData));
//--------------------------------------------------------------------------------------------
/** @ingroup IIoctlOperation
 * @brief Destructor of the IOCTL Operation interface instance
 * Destroys an IOCTL operation interface instance
 *
 * @param me           The reference to the interface instance
 */
void IIoctlOperation_destroy(IIoctlOperationRef me);

//--------------------------------------------------------------------------------------------
/** @ingroup IIoctlOperation
 * @brief Interface performing an IOCTL request
 * Interface to run an IOCTL request
 *
 * @param me           A reference to my instance
 * @param fileName     The pathname of the file/device to run the call on
 * @param request      The device dependent IOCTL request code
 * @param arp          An untyped pointer to memory, see your real ioctl call for more info
 * @return Depending on the IOCTL request, usually 0 on success and -1 on error with errno set
 */
int IIoctlOperation_request(IIoctlOperationRef me, const char* fileName, unsigned long request, void* argp);
//--------------------------------------------------------------------------------------------
/** @ingroup IIoctlOperation
 * @brief Interface performing a MMC IOCTL request
 * Interface to run a MMC IOCTL request. The MMC ioctl is different as the normal ioctl, thus a
 * special abstraction is needed.
 *
 * @param me           A reference to my instance
 * @param devPath      The pathname of the mmc device to run the call on
 * @param pIocCmd      A pointer to the IOC command
 * @param pData        A pointer to a memory area where the data can be stored to (depends on the IocCmd)
 * @return The response is stored to pData
 */
void IIoctlOperation_mmcRequest(IIoctlOperationRef me, const char* devPath, void* pIocCmd, void* pData);


#ifdef __cplusplus
}
#endif

#endif /* INCLUDE_NMAPP_FILE_IIOCTLOPERATION_H_ */
