/*********************************************************************************************
 * (c) COPYRIGHT 2020 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * temperature Header
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : temperature.h
 * CREATION DATE : Apr 8, 2020
 * TARGET        : embedded Linux
 *
 *********************************************************************************************/
#ifndef _SENSOR_TEMPERATURE_H_
#define _SENSOR_TEMPERATURE_H_


#include <nmapp/types/nm-types.h>
#include <nmapp/logging/ILog.h>
#include <nmapp/file/IFileOperation.h>

/** @ingroup libnmapp
 * @defgroup temperature Temperature
 * Provides functions reading a temperature sensor based on the file
 * system using the FileOperation interface.
 */
#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        GLOBAL DECLARATIONS
 *********************************************************************************************/

/** Temperature object reference */
typedef struct __TemperaturePrivate * TemperatureRef;


/** Temperature sensor identification */
typedef enum __TemperatureId
{
    TEMP_NONE = 0,           //!< No sensor ID
    TEMP_SYS  = 1,           //!< System temperature, e.g. CPU temperature
    TEMP_ENV  = 2,           //!< Environment temperature
    TEMP_MAX
} TemperatureId_t;


/*********************************************************************************************
 *        GLOBAL FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
/** @ingroup temperature
 * @brief Create Temperature Instance
 * Creates a temperature instance
 *
 * @param sesnorId      The ID of the sensor to read from
 * @param fileOpRef     A reference to the file operation interface
 * @param sensorPath    The pathname to the sensor temperature
 * @param logRef        A reference to the logger to use
 * @return The reference of the created instance
 */
TemperatureRef Temperature_create(TemperatureId_t sensorId, IFileOperationRef fileOpRef, const char* sensorPath, ILogRef logRef);
//--------------------------------------------------------------------------------------------
/** @ingroup temperature
 * @brief Destroy Temperature Instance
 * Destroys a temperature instance
 *
 * @param me            A reference to a temperature instance
 */
void Temperature_destroy(TemperatureRef me);
//--------------------------------------------------------------------------------------------
/** @ingroup temperature
 * @brief Read Temperature
 * Reads the temperature of the given instance
 *
 * @param me            A reference to a temperature instance
 * @return The read tempeture [°C]
 */
float64_t Temperature_read(TemperatureRef me);


#ifdef __cplusplus
}
#endif

#endif /* INCLUDE_NMAPP_SENSOR_TEMPERATURE_H_ */
