/*********************************************************************************************
 * (c) COPYRIGHT 2020 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * system MODULE
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : system.h
 * CREATION DATE : Apr 1, 2020
 * TARGET        : embedded Linux
 *
 *********************************************************************************************/
#ifndef INCLUDE_NMAPP_SYS_SYSTEM_H_
#define INCLUDE_NMAPP_SYS_SYSTEM_H_

/** @ingroup libnmapp
 * @defgroup system System Functions
 * Provides system function such as uptime, cpu load, ...
 */

#include <nmapp/types/nm-types.h>

#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        GLOBAL DECLARATIONS
 *********************************************************************************************/

enum
{
    SYS_DISKUSAGE_TOTAL     = 0,
    SYS_DISKUSAGE_USED      = 1,
    SYS_DISKUSAGE_AVAILABLE = 2,
    SYS_DISKUSAGE_FREE      = 3,
    SYS_DISKUSAGE_MAX
};

enum
{
    SYS_CPULOAD_1MIN  = 0,
    SYS_CPULOAD_5MIN  = 1,
    SYS_CPULOAD_15MIN = 2,
    SYS_CPULOAD_MAX
};



/*********************************************************************************************
 *        GLOBAL FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
/** @ingroup system
 * @brief Get Disk Usage Information
 * Returns the disk usage information of a file system: total, used, available, free
 *
 * @param path    The path on the mounted file system
 * @return The disk usage info (total, used, available, free)  in MB
 */
float64_t* System_getDiskUsageInfo(const char* path);
//--------------------------------------------------------------------------------------------
/** @ingroup system
 * @brief Get Available RAM
 * Returns the available RAM
 *
 * @return The available RAM in KB
 */
uint32_t System_getAvailableRAM(void);
//--------------------------------------------------------------------------------------------
/** @ingroup system
 * @brief Get CPU Load
 * Returns the CPU load tripple (array of 3 float64_t)
 *
 * @return The available RAM in KB
 */
float64_t* System_getCpuLoad(void);
//--------------------------------------------------------------------------------------------
/** @ingroup system
 * @brief Get Uptime
 * Returns the system uptime in seconds
 *
 * @return The system uptime in seconds
 */
uint64_t System_getUptime(void);


#ifdef __cplusplus
}
#endif

#endif /* INCLUDE_NMAPP_SYS_SYSTEM_H_ */
