/*********************************************************************************************
 * (c) COPYRIGHT 2020 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * NetModule Types HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : nm-types.h
 * CREATION DATE : Mar 24, 2020
 * TARGET        : generic
 *
 *********************************************************************************************/
#ifndef _NM_TYPES_H_
#define _NM_TYPES_H_

/** @ingroup libnmapp
* @defgroup nmtypes NetModule Types
* Types at NetModule containing type definitions that are used user specific appliations.
* Therefore the stdint- and stdbool header files define the types such as intN_t and uintN_t
* (where N represents the number of bits).\n
* Floating point values are manually defined\n\n
* @{
*/

#ifdef __cplusplus
extern "C" {
#endif


#include <stdint.h>         // for integer standard types
#include <stdbool.h>        // for boolean standard type
#include <stddef.h>         // for size_t, etc.
#include <ctype.h>          // for isspace, etc

#include <errno.h>          // for error number
#include <string.h>         // for strerror
#include <stdarg.h>         // for variable function arguments
#include <assert.h>         // for having assert available


/*********************************************************************************************
 *        GLOBAL DECLARATIONS
 *********************************************************************************************/

/** define the float types */
typedef float   float32_t;
typedef double  float64_t;

/** type for generic c object pointers (simplifies the handling with double-pointer structures) */
typedef void * GenericTypeRef;

/** type fore generic callback function pointers */
typedef int32_t (* GenericCallback)(GenericTypeRef calleCtx, int32_t info);

/** factors for SI conversions and other constants*/
#define FACTOR_NANO                  1.0E-9
#define FACTOR_MICRO                 1.0E-6
#define FACTOR_MILLI                 1.0E-3
#define FACTOR_KILO                  1E3
#define FACTOR_MEGA                  1E6
#define FACTOR_GIGA                  1E9

/** Digital size definitions */
#define DIGITAL_KILO                  1024
#define DIGITAL_MEGA                  (DIGITAL_KILO * DIGITAL_KILO)
#define DIGITAL_GIGA                  (DIGITAL_MEGA * DIGITAL_KILO)


/** time constants */
#define NANOSECONDS_PER_SECOND       1E9
#define MILLISECONDS_PER_SECOND      1E3
#define MICROSECONDS_PER_MILLISECOND 1E3
#define MICROSECONDS_PER_SECOND      1E6
#define NANOSECONDS_PER_MICROSECOND  1E3
#define NANOSECONDS_PER_MILLISECOND  1E6
#define HOURS_PER_DAY                24
#define SECONDS_PER_MINUTE           60
#define MINUTES_PER_HOUR             60
#define SECONDS_PER_HOUR             (SECONDS_PER_MINUTE * MINUTES_PER_HOUR)
#define MINUTES_PER_DAY              (HOURS_PER_DAY * MINUTES_PER_HOUR)
#define SECONDS_PER_DAY              (MINUTES_PER_DAY * SECONDS_PER_MINUTE)
#define MILLISECONDS_PER_DAY         (SECONDS_PER_DAY * MILLISECONDS_PER_SECOND)

#define PI                           3.141592653589f

/** Macro returning the maximum of two values */
#define MAX(a,b)                 \
   ({ __typeof__ (a) _a = (a); \
       __typeof__ (b) _b = (b);  \
     _a > _b ? _a : _b;          \
   })

/** Macro returning the minimum of two values */
#define MIN(a,b)                  \
    ({ __typeof__ (a) _a = (a); \
       __typeof__ (b) _b = (b);   \
     _a < _b ? _a : _b;           \
    })


//! @}

#ifdef __cplusplus
}
#endif

#endif /* _NM_TYPES_H_ */

/************************************END OF FILE*********************************************/
