/*********************************************************************************************
 * (c) COPYRIGHT 2020 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * List Private HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : list-private.h
 * CREATION DATE : Mar 30, 2020
 * TARGET        : generic
 *
 *********************************************************************************************/
#ifndef _LIST_PRIVATE_H_
#define _LIST_PRIVATE_H_

#include "../../include/nmapp/container/list.h"

#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        PRIVATE DECLARATIONS
 *********************************************************************************************/
/** List Handler content */
typedef struct ListPrivate {
    ListElem_t* pFirstElem;                             //!< First element in the list = top element
    ListElem_t* pLastElem;                              //!< Last element in the list  = bottom element
} ListPrivate_t;



/*********************************************************************************************
 *        PRIVATE FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
/** @brief Is List Empty
 * Returns whether the list is empty or not
 *
 * @param listRef   A reference to the list
 * @return true = list is empty, false = otherwise
 */
bool isListEmpty(ListRef listRef);
//--------------------------------------------------------------------------------------------
/** @brief Is Element Linked
 * Returns whether the element is linked
 *
 * @param pElem    A reference to a list element
 * @return true = element is linked, false = otherwise
 */
bool isElementLinked(ListElem_t* pElem);
//--------------------------------------------------------------------------------------------
/** @brief Is Element the Last in the List
 * Returns whether the element is the last in the list
 *
 * @param pElem    A reference to a list element
 * @return true = element is the last, false = otherwise
 */
bool isLastElement(ListElem_t* pElem);
//--------------------------------------------------------------------------------------------
/** @brief Is Element the First in the List
 * Returns whether the element is the first in the list
 *
 * @param pElem    A reference to a list element
 * @return true = element is the first, false = otherwise
 */
bool isFirstElement(ListElem_t* pElem);



//--------------------------------------------------------------------------------------------
// FOR TESTS ONLY:
//--------------------------------------------------------------------------------------------
void List_print(ListRef listRef);
//--------------------------------------------------------------------------------------------
void List_setupNotEmptyList(ListRef list);


#ifdef __cplusplus
}
#endif

#endif /* _LIST_PRIVATE_H_ */
