/*********************************************************************************************
 * (c) COPYRIGHT 2020 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * conversion MODULE
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : conversion.c
 * CREATION DATE : Apr 7, 2020
 * TARGET        : generic
 *
 *********************************************************************************************/

#include <stdlib.h>                    // for string to int, uint, float
#include <errno.h>                     // for error number
#include <limits.h>                    // for MAX integer values
#include <nmapp/exception/exception.h>
#include <nmapp/conversion/conversion.h>


/*********************************************************************************************
 *        LOCALS
 *********************************************************************************************/


/*********************************************************************************************
 *        GLOBALS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
int32_t str2int(char *str)
{
    char    *origStr = str;
    char    *endPtr  = NULL;
    long int result  = 0;

    errno  = 0;
    result = strtol(str, &endPtr, 10);
    if( ((errno == ERANGE) && ((result == LONG_MAX) || (result == LONG_MIN))) ||
        ((errno != 0) && (result == 0)) )
    {
        Throw(EX_CONVERSION, "Converting %s to int32_t", origStr);
    }
    if(endPtr == str)
    {
        Throw(EX_CONVERSION, "No digits found in %s to convert into int32_t", origStr);
    }
    if ( !((*endPtr == '\0') && (*str != '\0')) ) // This is the last paranoia check for failure :-)
    {
        Throw(EX_CONVERSION, "Converting %s to int32_t (end)", origStr);
    }
    return (int32_t)result;
}
//--------------------------------------------------------------------------------------------
uint32_t str2uint(char *str)
{
    char     *origStr = str;
    char     *endPtr  = NULL;
    unsigned long int result  = 0;

    errno  = 0;
    result = strtoul(str, &endPtr, 10);
    if( ((errno == ERANGE) && (result == ULONG_MAX)) || ((errno != 0) && (result == 0)) )
    {
        Throw(EX_CONVERSION, "Converting %s to uint32_t", origStr);
    }
    if(endPtr == str)
    {
        Throw(EX_CONVERSION, "No digits found in %s to convert into uint32_t", origStr);
    }
    if ( !((*endPtr == '\0') && (*str != '\0')) ) // This is the last paranoia check for failure :-)
    {
        Throw(EX_CONVERSION, "Converting %s to uint32_t (end)", origStr);
    }
    return (uint32_t)result;
}
//--------------------------------------------------------------------------------------------
uint32_t str2hex(char *str)
{
    char     *origStr = str;
    char     *endPtr  = NULL;
    unsigned long int result  = 0;

    errno  = 0;
    result = strtoul(str, &endPtr, 16);
    if( ((errno == ERANGE) && (result == ULONG_MAX)) || ((errno != 0) && (result == 0)) )
    {
        Throw(EX_CONVERSION, "Converting %s to HEX", origStr);
    }
    if(endPtr == str)
    {
        Throw(EX_CONVERSION, "No digits found in %s to convert into HEX", origStr);
    }
    if ( !((*endPtr == '\0') && (*str != '\0')) ) // This is the last paranoia check for failure :-)
    {
        Throw(EX_CONVERSION, "Converting %s to HEX (end)", origStr);
    }
    return (uint32_t)result;
}
//--------------------------------------------------------------------------------------------
float64_t str2float(char *str)
{
    char      *origStr = str;
    char      *endPtr  = NULL;
    float64_t  result  = 0.0;

    errno  = 0;
    result = (float64_t)strtod(str, &endPtr);
    if(errno == ERANGE)
    {
        Throw(EX_CONVERSION, "Converting %s to float64_t", origStr);
    }
    if(endPtr == str)
    {
        Throw(EX_CONVERSION, "No conversion into float64_t done with %s", origStr);
    }
    if ( !((*endPtr == '\0') && (*str != '\0')) ) // This is the last paranoia check for failure :-)
    {
        Throw(EX_CONVERSION, "Converting %s to float64_t (end)", origStr);
    }
    return result;
}

