/*********************************************************************************************
 * (c) COPYRIGHT 2021 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * IIoctlOperation MODULE
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : IIoctlOperation.c
 * CREATION DATE : Oct 21, 2021
 * TARGET        : generic
 *
 *********************************************************************************************/

#include <stdlib.h>                         // for calloc, free, ...
#include <nmapp/types/nm-types.h>
#include <nmapp/exception/exception.h>
#include <nmapp/sys/assertion.h>
#include "IIoctlOperation-protected.h"

/*********************************************************************************************
 *        LOCALS
 *********************************************************************************************/


/*********************************************************************************************
 *        GLOBALS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
IIoctlOperationRef IIoctlOperation_ctor(IIoctlOperationImplRef implRef,
                                        int  (*request)(IIoctlOperationImplRef implRef, const char* fileName, unsigned long request, void* argp),
                                        void (*mmcRequest)(IIoctlOperationImplRef implRef, const char* devPath, void* pIocCmd, void* pData))
{
    assert(request != NULL);

    IIoctlOperationRef me = (IIoctlOperationRef)calloc(1, sizeof(IIoctlOperationProtected_t));
    assert(me != NULL);
    me->myImpl = implRef;
    me->request = request;
    me->mmcRequest = mmcRequest;
    return me;
}
//--------------------------------------------------------------------------------------------
void IIoctlOperation_destroy(IIoctlOperationRef me)
{
    if(me != NULL)
    {
        free(me);
    }
}

//--------------------------------------------------------------------------------------------
int IIoctlOperation_request(IIoctlOperationRef me, const char* fileName, unsigned long request, void* argp)
{
    assert(me != NULL);
    return me->request(me->myImpl, fileName, request, argp);
}
//--------------------------------------------------------------------------------------------
void IIoctlOperation_mmcRequest(IIoctlOperationRef me, const char* devPath, void* pIocCmd, void* pData)
{
    assert(me != NULL);
    me->mmcRequest(me->myImpl, devPath, pIocCmd, pData);
}
