/*********************************************************************************************
 * (c) COPYRIGHT 2020 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * Logging Interface
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : ILog.c
 * CREATION DATE : Mar 24, 2020
 * TARGET        : generic
 *
 *********************************************************************************************/

#include <stdlib.h>                    // for calloc
#include <nmapp/logging/ILog-protected.h>

#ifdef __cplusplus
extern "C" {
#endif

/*********************************************************************************************
 *        LOCALS
 *********************************************************************************************/

// Enums / Structs / Unions:
//-----------------------------------------
typedef struct __ILogPrivate
{
    ILogImplRef   myImpl;
    LogLevel_t    maxLogLevel;
    void (*log_msg)(ILogImplRef me, LogLevel_t logLevel, const char * msg, va_list args);
} ILogPrivate_t;


// Variables:
//-----------------------------------------
static ILogRef sysLogger = NULL;


/*********************************************************************************************
 *        GLOBAL FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
ILogRef ILog_ctor(ILogImplRef implRef, bool isSysLogger, LogLevel_t maxLogLevel,
                  void (*log_msg)(ILogImplRef me, LogLevel_t logLevel, const char * msg, va_list args))
{
    ILogRef me = (ILogRef)calloc(1, sizeof(ILogPrivate_t));
    assert(me != NULL);
    assert(log_msg != NULL);
    assert(implRef != NULL);

    me->myImpl = implRef;
    me->log_msg = log_msg;
    me->maxLogLevel = maxLogLevel;

    if(isSysLogger)
    {
        sysLogger = me;
    }

    return me;
}
//--------------------------------------------------------------------------------------------
void ILog_msg(ILogRef me, LogLevel_t logLevel, const char * msg, ...)
{
    me = (me == NULL) ? sysLogger : me;
    assert(me != NULL);
    if(logLevel <= me->maxLogLevel)
    {
        assert(me->log_msg != NULL);
        va_list args;
        va_start(args, msg);
        me->log_msg(me->myImpl, logLevel, msg, args);
        va_end(args);
    }
}
//--------------------------------------------------------------------------------------------
void ILog_setMaxLogLevel(ILogRef me, LogLevel_t logLevel)
{
    me = (me == NULL) ? sysLogger : me;
    assert(me != NULL);
    me->maxLogLevel = logLevel;
}
//--------------------------------------------------------------------------------------------
LogLevel_t ILog_getMaxLogLevel(ILogRef me)
{
    me = (me == NULL) ? sysLogger : me;
    assert(me != NULL);
    return me->maxLogLevel;
}
//--------------------------------------------------------------------------------------------
void ILog_destroy(ILogRef me)
{
    if(me != NULL)
    {
        free(me);
    }
}

#ifdef __cplusplus
}
#endif

/************************************END OF FILE*********************************************/
