/*********************************************************************************************
 * (c) COPYRIGHT 2020 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * SysLogger_private HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : SysLogger_private.h
 * CREATION DATE : Mar 24, 2020
 * TARGET        : embedded Linux
 *
 *********************************************************************************************/
#ifndef _SYSLOGGER_PRIVATE_H_
#define _SYSLOGGER_PRIVATE_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <nmapp/logging/SysLogger.h>
#include <nmapp/sys/IUnixInitSys.h>

/*********************************************************************************************
 *        PRIVATE DECLARATIONS
 *********************************************************************************************/

// Definitions:
//-----------------------------------------
typedef ILogRef (*getLoggerInstFn)(const char * name, bool addIfMissing);
typedef ILogRef (*addLoggerFn)(const char * name, SysLogFacility_t logFacility, LogLevel_t maxLogLevel, bool useSyslog, bool useStdout);

#define SYSLOGGER_NAME  "system"

extern const char* SYSLOG_LEVEL_NAME[LOG_LEVEL_MAX];

typedef struct __SysLoggerPrivate
{
    ILogRef           myLogItf;
    IUnixInitSysRef   initSysItfRef;
    const char*       appName;
    char*             loggerName;
    SysLogFacility_t  logFacility;
    LogLevel_t        maxLogLevel;
    bool              useSyslog;
    bool              useStdout;
} SysLoggerPrivate_t;


// Variables:
//-----------------------------------------
extern SysLoggerRef sysLogger;                                  // Singleton
extern SysLoggerRef addedLoggers[SYSLOG_MAX_NBR_OF_LOGGERS];    // Added loggers


/*********************************************************************************************
 *        FOR UNIT TESTS ONLY
 *********************************************************************************************/
ILogRef getLoggerInst(const char * name, bool addIfMissing);
ILogRef addLogger(const char * name, SysLogFacility_t logFacility, LogLevel_t maxLogLevel, bool useSyslog, bool useStdout);

void SysLogger_setupTestFunctions(getLoggerInstFn getLoggerFnRef, addLoggerFn addLoggerFnRef);


#ifdef __cplusplus
}
#endif

#endif  //_SYSLOGGER_PRIVATE_H_

/************************************END OF FILE*********************************************/
