/*********************************************************************************************
 * (c) COPYRIGHT 2021 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * IUnixInitSys (realization part of the interface)
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : IUnixInitSys.c
 * CREATION DATE : Jan 20, 2021
 * TARGET        : generic
 *
 *********************************************************************************************/

#include <stdlib.h>                         // for calloc, free, ...
#include <nmapp/types/nm-types.h>
#include <nmapp/exception/exception.h>
#include <nmapp/sys/assertion.h>
#include "IUnixInitSys-protected.h"


/*********************************************************************************************
 *        LOCALS
 *********************************************************************************************/


/*********************************************************************************************
 *        GLOBALS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
IUnixInitSysRef IUnixInitSys_ctor(IUnixInitSysImplRef implRef,
                                  void  (*logMessage)(IUnixInitSysImplRef implRef, int32_t logPriority, int32_t facility, const char* loggerName, const char* msg),
                                  void  (*initDBus)(IUnixInitSysImplRef implRef),
                                  void  (*deinitDBus)(IUnixInitSysImplRef implRef),
                                  int   (*getEventFd)(IUnixInitSysImplRef implRef),
                                  void  (*registerDBusSignalCallback)(IUnixInitSysImplRef implRef, UnixInitSysDBusSignalItemCallback cbFn, void* pCbCtx),
                                  void  (*activateDBusListener)(IUnixInitSysImplRef implRef),
                                  void  (*processDBusEvents)(IUnixInitSysImplRef implRef),
                                  void* (*registerDBusSignalMatch)(IUnixInitSysImplRef implRef, const char* dbusService, const char* dbusObjPath,
                                                                    const char* dbusItfName, const char* dbusSignalName),
                                  void  (*unregisterDBusSignalMatch)(IUnixInitSysImplRef implRef, void* signalMatchRef),
                                  const char* (*getOperatingState)(IUnixInitSysImplRef me))
{
    assert(implRef != NULL);

    assert(logMessage != NULL);
    assert(initDBus != NULL);
    assert(deinitDBus != NULL);
    assert(getEventFd != NULL);
    assert(registerDBusSignalCallback != NULL);
    assert(activateDBusListener != NULL);
    assert(processDBusEvents != NULL);
    assert(registerDBusSignalMatch != NULL);
    assert(unregisterDBusSignalMatch != NULL);
    assert(getOperatingState != NULL);

    IUnixInitSysRef me = (IUnixInitSysRef)calloc(1, sizeof(IUnixInitSysProtected_t));
    assert(me != NULL);

    me->myImpl = implRef;
    me->logMessage = logMessage;
    me->initDBus   = initDBus;
    me->deinitDBus = deinitDBus;
    me->getEventFd = getEventFd;
    me->registerDBusSignalCallback = registerDBusSignalCallback;
    me->activateDBusListener       = activateDBusListener;
    me->processDBusEvents          = processDBusEvents;
    me->registerDBusSignalMatch    = registerDBusSignalMatch;
    me->unregisterDBusSignalMatch  = unregisterDBusSignalMatch;
    me->getOperatingState          = getOperatingState;

    return me;
}
//--------------------------------------------------------------------------------------------
void IUnixInitSys_destroy(IUnixInitSysRef me)
{
    if(me != NULL)
    {
        free(me);
    }
}

//--------------------------------------------------------------------------------------------
void IUnixInitSys_logMessage(IUnixInitSysRef me, int32_t logPriority, int32_t facility, const char* loggerName, const char* msg)
{
    assert(me != NULL);
    me->logMessage(me->myImpl, logPriority, facility, loggerName, msg);
}

//--------------------------------------------------------------------------------------------
void IUnixInitSys_initDBus(IUnixInitSysRef me)
{
    assert(me != NULL);
    me->initDBus(me->myImpl);
}
//--------------------------------------------------------------------------------------------
void IUnixInitSys_deinitDBus(IUnixInitSysRef me)
{
    assert(me != NULL);
    me->deinitDBus(me->myImpl);
}
//--------------------------------------------------------------------------------------------
int IUnixInitSys_getEventFileDescriptor(IUnixInitSysRef me)
{
    assert(me != NULL);
    return me->getEventFd(me->myImpl);
}
//--------------------------------------------------------------------------------------------
void IUnixInitSys_registerDBusSignalCallback(IUnixInitSysRef me, UnixInitSysDBusSignalItemCallback cbFn, void* pCbCtx)
{
    assert(me != NULL);
    me->registerDBusSignalCallback(me->myImpl, cbFn, pCbCtx);
}
//--------------------------------------------------------------------------------------------
void IUnixInitSys_activateDBusListener(IUnixInitSysRef me)
{
    assert(me != NULL);
    me->activateDBusListener(me->myImpl);
}
//--------------------------------------------------------------------------------------------
void IUnixInitSys_processDBusEvents(IUnixInitSysRef me)
{
    assert(me != NULL);
    me->processDBusEvents(me->myImpl);
}
//--------------------------------------------------------------------------------------------
void* IUnixInitSys_registerDBusSignalMatch(IUnixInitSysRef me, const char* dbusService, const char* dbusObjPath,
                                          const char* dbusItfName, const char* dbusSignalName)
{
    assert(me != NULL);
    return me->registerDBusSignalMatch(me->myImpl, dbusService, dbusObjPath, dbusItfName, dbusSignalName);
}
//--------------------------------------------------------------------------------------------
void IUnixInitSys_unregisterDBusSignalMatch(IUnixInitSysRef me, void* signalMatchRef)
{
    assert(me != NULL);
    me->unregisterDBusSignalMatch(me->myImpl, signalMatchRef);
}
//--------------------------------------------------------------------------------------------
const char* IUnixInitSys_getOperatingState(IUnixInitSysRef me)
{
    assert(me != NULL);
    return me->getOperatingState(me->myImpl);
}

