/*********************************************************************************************
 * (c) COPYRIGHT 2021 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * UnixInitSys-private MODULE
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : UnixInitSys-private.h
 * CREATION DATE : Jan 18, 2021
 * TARGET        : generic
 *
 *********************************************************************************************/
#ifndef SRC_SYS_UNIXINITSYS_PRIVATE_H_
#define SRC_SYS_UNIXINITSYS_PRIVATE_H_

#include <nmapp/sys/UnixInitSys.h>

#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        PRIAVTE DECLARATIONS
 *********************************************************************************************/

#define UNIX_INIT_SYS_BUF_SIZE 64


typedef struct __UnixInitSysBusPrivate * UnixInitSysBusRef;

// function pointers for systemd encapsulation:
typedef int          (*journalLog_fn)(const char*, ...);
typedef int          (*sdeventDefault_fn)(sd_event**);
typedef int          (*sdeventGetFd_fn)(sd_event*);
typedef int          (*sdeventPrepare_fn)(sd_event*);
typedef int          (*sdeventDispatch_fn)(sd_event*);
typedef int          (*sdeventWait_fn)(sd_event*, uint64_t);
typedef int          (*sdeventPrepare_fn)(sd_event*);
typedef sd_event*    (*sdeventUnref_fn)(sd_event*);
typedef int          (*sdbusSystemOpen_fn)(sd_bus**);
typedef void         (*sdbusClose_fn)(sd_bus*);
typedef int          (*sdbusAttachEvent_fn)(sd_bus*, sd_event*, int);
typedef int          (*sdbusMatchSignal_fn)(sd_bus*, sd_bus_slot**, const char*, const char*, const char*, const char*, sd_bus_message_handler_t, void*);
typedef const char*  (*sdbusMsgGetDest_fn)(sd_bus_message*);
typedef const char*  (*sdbusMsgGetPath_fn)(sd_bus_message*);
typedef const char*  (*sdbusMsgGetItf_fn)(sd_bus_message*);
typedef const char*  (*sdbusMsgGetMember_fn)(sd_bus_message*);
typedef int          (*sdbusMsgReadBasic_fn)(sd_bus_message*, char, void*);
typedef int          (*sdbusGetPropertyString_fn)(sd_bus*, const char*, const char*, const char*, const char*, sd_bus_error*, char**);
typedef sd_bus_slot* (*sdbusUnrefSlot_fn)(sd_bus_slot*);


typedef struct __UnixInitSysPrivate
{
    ILogRef              logRef;
    IUnixInitSysRef      itf;
    UnixInitSysBusRef    busRef;
    int                  fdEvent;
    char                 opState[UNIX_INIT_SYS_BUF_SIZE];
    const char*          appName;
    bool                 useSysLog;

    journalLog_fn        logToJournal;
    sdeventDefault_fn    sdEventDefault;
    sdeventGetFd_fn      sdEventGetFd;
    sdeventPrepare_fn    sdEventPrepare;
    sdeventDispatch_fn   sdEventDispatch;
    sdeventWait_fn       sdEventWait;
    sdeventUnref_fn      sdEventUnref;
    sdbusSystemOpen_fn   sdbusSysOpen;
    sdbusClose_fn        sdbusClose;
    sdbusAttachEvent_fn  sdbusAttachEvent;
    sdbusMatchSignal_fn  sdbusMatchSignal;
    sdbusMsgGetDest_fn   sdbusMsgGetDest;
    sdbusMsgGetPath_fn   sdbusMsgGetPath;
    sdbusMsgGetItf_fn    sdbusMsgGetItf;
    sdbusMsgGetMember_fn sdbusMsgGetMember;
    sdbusMsgReadBasic_fn sdbusMsgReadBasic;
    sdbusUnrefSlot_fn    sdbusUnrefSlot;
    sdbusGetPropertyString_fn sdbusGetPropertyStr;
} UnixInitSysPrivate_t;



/*********************************************************************************************
 *        PRIVATE FUNCTIONS
 *********************************************************************************************/


#ifdef __cplusplus
}
#endif

#endif /* SRC_SYS_UNIXINITSYS_PRIVATE_H_ */
