/*********************************************************************************************
 * (c) COPYRIGHT 2020 by NetModule AG, Switzerland.  All rights reserved.
 * -------------------------------------------------------------------------------------------
 *
 * System Private HEADER
 *
 * -------------------------------------------------------------------------------------------
 *
 * FILENAME      : system-private.h
 * CREATION DATE : Apr 20, 2020
 * TARGET        : embedded Linux
 *
 *********************************************************************************************/
#ifndef _SYSTEM_PRIVATE_H_
#define _SYSTEM_PRIVATE_H_

#include <nmapp/types/nm-types.h>
#include <nmapp/sys/system.h>

#ifdef __cplusplus
extern "C" {
#endif


/*********************************************************************************************
 *        PRIVATE DECLARATIONS
 *********************************************************************************************/

typedef float64_t* (*getDiskUsageFn)(const char*);
typedef uint32_t   (*getAvailableRAMFn)(void);
typedef float64_t* (*getCpuLoadFn)(void);
typedef uint64_t   (*getUptimeFn)(void);


typedef struct __SystemPrivate
{
    uint32_t  availableRamKb;
    float64_t diskUsageMB[SYS_DISKUSAGE_MAX];
    float64_t cpuLoadTripple[SYS_CPULOAD_MAX];

    getDiskUsageFn    pGetDiskUsage;
    getAvailableRAMFn pGetAvailableRAM;
    getCpuLoadFn      pGetCpuLoad;
    getUptimeFn       pGetUptime;
} SystemPrivat_t;


/*********************************************************************************************
 *        PRIVATE FUNCTIONS
 *********************************************************************************************/
//--------------------------------------------------------------------------------------------
float64_t* getDiskUsageInfo(const char* path);

//--------------------------------------------------------------------------------------------
uint32_t getAvailableRAM(void);

//--------------------------------------------------------------------------------------------
float64_t* getCpuLoad(void);

//--------------------------------------------------------------------------------------------
uint64_t getUptime(void);

/*********************************************************************************************
 *        FOR UNIT TESTS ONLY
 *********************************************************************************************/
void System_setupSystemCalls(getDiskUsageFn getDiskUsageRef,
                             getAvailableRAMFn getAvailableRamRef,
                             getCpuLoadFn getCpuLoadRef,
                             getUptimeFn getUptimeRef);


#ifdef __cplusplus
}
#endif

#endif /* SRC_SYS_SYSTEM_PRIVATE_H_ */
